# Flutter Feedback

Flutter feedback is a package that allows the users to give feedback, report issues, look at the privacy policy, terms of service and about page. Also this package shows the current version and buildnumber of the app. This package has a firebase implementation for collecting feedback and issues. You could also use your own backend by extending the `feedback_repository_interface`.

## Setup

To use this package, add flutter_feedback as a dependency in your pubspec.yaml file:

```yaml
dependencies:
  flutter_feedback: 
    hosted: https://forgejo.internal.iconica.nl/api/packages/internal/pub
    version: <current version>
```

You can use the `LocalFeedbackRepository` for testing this package. This is the service that is used by default:

```dart
FlutterFeedbackNavigatorUserstory(
    feedbackService: FeedbackService(),
);
```


Or you can use the `FirebaseFeedbackRepository` for production. Before you can use this service you will need to import the `FirebaseFeedbackRepository`:

```yaml
dependencies:
  firebase_feedback_repository: 
    hosted: https://forgejo.internal.iconica.nl/api/packages/internal/pub
    version: <current version>
```

and then you can use the `FirebaseFeedbackRepository`:

```dart
FlutterFeedbackNavigatorUserstory(
    feedbackService: FirebaseFeedbackRepository(),
);
```

## Usage

To use flutter feedback add the `FlutterFeedbackNavigatorUserstory` to your widget tree like so:

```dart
class Example extends StatelessWidget {
  const Example({super.key});

  @override
  Widget build(BuildContext context) {
    return const FlutterFeedbackNavigatorUserstory();
  }
}
```

## Configuration

You can use `FeedbackConfiguration` to configure the feedback page.

| Parameter | Explanation |
|-----------|-------------|
|privacyPolicyControls|Overrides the default `Control` that is used to display the "Privacy Policy" website|
|termsOfServiceControls|Overrides the default `Control` that is used to display the "Terms of Service" website|
|feedbackControls|Overrides the default `Control` that is used to display the "Give Us Feedback" popup|
|aboutUsControls| Overrides the default `Control` that is used to display the "About Us" page|
|onTapAboutUs|Function that overrides the default implementation of the "About Us" button|
|onTapPrivacyPolicy|Function that overrides the default implementation of the "Privacy Policy" button|
|onTapTermsOfService|Function that overrides the default implementation of the "Terms of Service" button|
|onTapFeedback| Function that overrides the default implementation of the "Give Us Feedback" button|
|privacyPolicyUrl|Specifies to which url the `urlLauncher` should go. when clicking the "Privacy Policy" Button|
|termsOfServiceUrl| Specifies to which url the `urlLauncher` should go. when clicking the "Terms of Service" Button|
|selectIssueCategory| Whether the user has to select an issue category when reporting an issue|
|reportIssueControls|Overrides the default `Control` that is used to display the "Report Issue" page|
|onTapReportIssue|Function that overrides the default implementation of the "Report Issue" button|
|logoUrl| path to the logo asset that is shown at the bottom of the initial page|
|showBuildNumber|Whetherthe buildnumber should be shown|
|useAbout|Whether the About section on the inital page should be shown|
|useFeedback|Whether the Feedback section on the inital page should be shown|
|useStoreReview|Whether the app should redirect to the app store when a user gives a 4 or 5 star rating|


You can use `FeedbackTranslations` to configure the translations of the feedback page.


## Issues

Please file any issues, bugs or feature request as an issue on our [GitHub](https://github.com/Iconica-Development/flutter_feedback/pulls) page. Commercial support is available if you need help with integration with your app or services. You can contact us at [support@iconica.nl](mailto:support@iconica.nl).

## Want to contribute

If you would like to contribute to the plugin (e.g. by improving the documentation, solving a bug or adding a cool new feature), please carefully review our [contribution guide](./CONTRIBUTING.md) and send us your [pull request](https://github.com/Iconica-Development/flutter_feedback/pulls).

## Author

This `flutter_feedback` for Flutter is developed by [Iconica](https://iconica.nl). You can contact us at <support@iconica.nl>



