import "package:feedback_repository_interface/src/interfaces/feedback_repository_interface.dart";
import "package:feedback_repository_interface/src/models/feedback_report.dart";
import "package:feedback_repository_interface/src/models/issue_report.dart";
import "package:shared_preferences/shared_preferences.dart";

///
class LocalFeedbackRepository implements FeedbackRepositoryInterface {
  ///
  LocalFeedbackRepository();

  final List<FeedbackReport> _feedbacks = [];
  final List<IssueReport> _reports = [];

  @override
  Future<void> sendFeedback({required FeedbackReport feedback}) async {
    _feedbacks.add(feedback);
  }

  @override
  Future<void> sendReport({required IssueReport report}) async {
    _reports.add(report);
  }

  @override
  Future<bool> shouldShowFeedbackPopup({required int showCount}) async {
    var prefs = await SharedPreferences.getInstance();
    var viewCount = prefs.getInt("feedbackViewCount") ?? 0;

    if (viewCount >= showCount) {
      await prefs.setInt("feedbackViewCount", 0);
      return true;
    }
    return false;
  }

  @override
  Future<void> addViewCount() async {
    var prefs = await SharedPreferences.getInstance();
    var viewCount = prefs.getInt("feedbackViewCount") ?? 0;
    await prefs.setInt("feedbackViewCount", viewCount++);
  }
}
