import "package:feedback_repository_interface/feedback_repository_interface.dart";

/// Report specifically for feedback
class FeedbackReport extends Report {
  ///
  const FeedbackReport({
    required super.appVersion,
    required this.rating,
    this.feedback,
    super.deviceModel,
    super.osVersion,
    super.platform,
    super.manufacturer,
    super.browserName,
    super.userId,
  });

  /// Convert FeedbackReport from JSON
  factory FeedbackReport.fromJson(Map<String, dynamic> json) => FeedbackReport(
        appVersion: json["appVersion"],
        userId: json["userId"],
        deviceModel: json["deviceModel"],
        osVersion: json["osVersion"],
        platform: json["platform"],
        manufacturer: json["manufacturer"],
        browserName: json["browserName"],
        feedback: json["feedback"],
        rating: json["rating"],
      );

  /// Given feedback by user
  final String? feedback;

  /// Given rating by user
  final int rating;

  /// Convert FeedbackReport to JSON
  @override
  Map<String, dynamic> toJson() {
    var data = super.toJson();
    data.addAll({
      "feedback": feedback,
      "rating": rating,
    });
    return data;
  }

  ///
  FeedbackReport copyWith({
    String? userId,
    String? appVersion,
    String? deviceModel,
    String? osVersion,
    String? platform,
    String? manufacturer,
    String? browserName,
    String? feedback,
    int? rating,
  }) =>
      FeedbackReport(
        userId: userId ?? this.userId,
        appVersion: appVersion ?? this.appVersion,
        deviceModel: deviceModel ?? this.deviceModel,
        osVersion: osVersion ?? this.osVersion,
        platform: platform ?? this.platform,
        manufacturer: manufacturer ?? this.manufacturer,
        browserName: browserName ?? this.browserName,
        feedback: feedback ?? this.feedback,
        rating: rating ?? this.rating,
      );

  @override
  String toString() => "${super.toString()}, "
      " FeedbackReport(feedback: $feedback, rating: $rating)";
}
