import "package:feedback_repository_interface/feedback_repository_interface.dart";

/// Report specifically for issues
class IssueReport extends Report {
  ///
  const IssueReport({
    required super.appVersion,
    this.issue,
    this.issueExplanation,
    super.deviceModel,
    super.osVersion,
    super.platform,
    super.manufacturer,
    super.browserName,
    super.userId,
  });

  /// Convert IssueReport from JSON
  factory IssueReport.fromJson(Map<String, dynamic> json) => IssueReport(
        appVersion: json["appVersion"],
        userId: json["userId"],
        deviceModel: json["deviceModel"],
        osVersion: json["osVersion"],
        platform: json["platform"],
        manufacturer: json["manufacturer"],
        browserName: json["browserName"],
        issue: json["issue"],
        issueExplanation: json["issueExplanation"],
      );

  /// Chosen issue by user
  final String? issue;

  /// Additional information on the issue created by user
  final String? issueExplanation;

  /// Convert IssueReport to JSON
  @override
  Map<String, dynamic> toJson() {
    var data = super.toJson();
    data.addAll({
      "issue": issue,
      "issueExplanation": issueExplanation,
    });
    return data;
  }

  ///
  IssueReport copyWith({
    String? userId,
    String? appVersion,
    String? deviceModel,
    String? osVersion,
    String? platform,
    String? manufacturer,
    String? browserName,
    String? issue,
    String? issueExplanation,
  }) =>
      IssueReport(
        userId: userId ?? this.userId,
        appVersion: appVersion ?? this.appVersion,
        deviceModel: deviceModel ?? this.deviceModel,
        osVersion: osVersion ?? this.osVersion,
        platform: platform ?? this.platform,
        manufacturer: manufacturer ?? this.manufacturer,
        browserName: browserName ?? this.browserName,
        issue: issue ?? this.issue,
        issueExplanation: issueExplanation ?? this.issueExplanation,
      );

  @override
  String toString() => "${super.toString()}, "
      "IssueReport(issue: $issue, issueExplanation: $issueExplanation)";
}
