/// Base class for reports
class Report {
  ///
  const Report({
    required this.appVersion,
    this.deviceModel,
    this.osVersion,
    this.platform,
    this.manufacturer,
    this.browserName,
    this.userId,
  });

  /// Convert report from JSON
  factory Report.fromJson(Map<String, dynamic> json) => Report(
        userId: json["userId"],
        appVersion: json["appVersion"],
        deviceModel: json["deviceModel"],
        osVersion: json["osVersion"],
        platform: json["platform"],
        manufacturer: json["manufacturer"],
        browserName: json["browserName"],
      );

  /// Optional user id of user who created the report
  final String? userId;

  /// App version on which the report has been created
  final String appVersion;

  /// Device model from which the report has been created
  final String? deviceModel;

  /// OS version from which the report has been created
  final String? osVersion;

  /// Platform from which the report has been created
  final String? platform;

  /// Manufacturer of device from which the report has been created
  final String? manufacturer;

  /// Browser from which the report has been created if created from web
  final String? browserName;

  /// Convert report to JSON
  Map<String, dynamic> toJson() => {
        "userId": userId,
        "appVersion": appVersion,
        "deviceModel": deviceModel,
        "osVersion": osVersion,
        "platform": platform,
        "manufacturer": manufacturer,
        "browserName": browserName,
      };

  @override
  String toString() => "Report("
      "userId: $userId, "
      "appVersion: $appVersion, "
      "deviceModel: $deviceModel, "
      "osVersion: $osVersion, "
      "platform: $platform, "
      "manufacturer: $manufacturer, "
      "browserName: $browserName"
      ")";
}
